pm4py.algo.organizational\_mining package
=========================================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pm4py.algo.organizational_mining.local_diagnostics
   pm4py.algo.organizational_mining.network_analysis
   pm4py.algo.organizational_mining.resource_profiles
   pm4py.algo.organizational_mining.roles
   pm4py.algo.organizational_mining.sna

Submodules
----------

pm4py.algo.organizational\_mining.util module
---------------------------------------------

.. automodule:: pm4py.algo.organizational_mining.util
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.algo.organizational_mining
   :members:
   :undoc-members:
   :show-inheritance:
